# Shortcut Functions for Log Operations

## Install

    pip install invisibleroads-macros-log

## Test

    git clone https://github.com/invisibleroads/invisibleroads-macros-log
    cd invisibleroads-macros-log
    pip install -e .[test]
    pytest --cov=invisibleroads_macros_log --cov-report term-missing tests
